==> deepin-deb-installer_1.2.4.orig.tar.gz: deepin-deb-installer-1.2.4/translations/deepin-deb-installer_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin paketų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Masinis įdiegimas</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Įdiegimas nepavyko, prašome patikrinti savo tinklo ryšį</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Įdiegimas nepavyko, prašome patikrinti atnaujinimus Valdymo centre</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Įdiegimas nepavyko, trūksta vietos diske</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Įdiegimas nepavyko</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Sugadintos priklausomybės: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Neatitinkanti paketo architektūra</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Vilkite failą čia</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Pasirinkti failą</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Suskleisti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Rodyti išsamiau</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Įdiegti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>Įdiegiama</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Įdiegta</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Nepavyko</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>Įdiegta ta pati versija</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>Įdiegta kita versija: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Suskleisti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Rodyti išsamiau</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Įdiegti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Įdiegti iš naujo</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Sėkmingai įdiegta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Sėkmingai pašalinta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>Įdiegta kita versija: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Šalinimas nepavyko</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Pavadinimas: </translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>Įdiegta ta pati versija</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Rodyti susijusius paketus</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Suskleisti</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Ar tikrai norite pašalinti %1?
Tuo pačiu bus pašalintos ir visos priklausomybės</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin paketų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Deepin paketų tvarkytuvė yra programa, naudojama padėti naudotojams įdiegti ir šalinti vietinę programinę įrangą, ši programa palaiko masinį įdiegimą.</translation>
    </message>
</context>
</TS>

==> deepin-deb-installer_1.2.5.orig.tar.gz: deepin-deb-installer-1.2.5/translations/deepin-deb-installer_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin paketų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Masinis įdiegimas</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Įdiegimas nepavyko, prašome patikrinti savo tinklo ryšį</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Įdiegimas nepavyko, prašome patikrinti atnaujinimus Valdymo centre</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Įdiegimas nepavyko, trūksta vietos diske</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Įdiegimas nepavyko</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Sugadintos priklausomybės: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Neatitinkanti paketo architektūra</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Vilkite failą čia</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Pasirinkti failą</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Suskleisti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Rodyti išsamiau</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Įdiegti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Atlikta</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>Įdiegiama</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Įdiegta</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Nepavyko</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>Įdiegta ta pati versija</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>Įdiegta kita versija: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Suskleisti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Rodyti išsamiau</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Įdiegti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Įdiegti iš naujo</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation>Atlikta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Sėkmingai įdiegta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Sėkmingai pašalinta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>Įdiegta kita versija: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Šalinimas nepavyko</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Pavadinimas: </translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>Įdiegta ta pati versija</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Rodyti susijusius paketus</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Suskleisti</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Ar tikrai norite pašalinti %1?
Tuo pačiu bus pašalintos ir visos priklausomybės</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin paketų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Deepin paketų tvarkytuvė yra programa, naudojama padėti naudotojams įdiegti ir šalinti vietinę programinę įrangą, ši programa palaiko masinį įdiegimą.</translation>
    </message>
</context>
</TS>
